summaryrefslogtreecommitdiffstats
path: root/chromium/base/debug/trace_event_memory_unittest.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/base/debug/trace_event_memory_unittest.cc')
-rw-r--r--chromium/base/debug/trace_event_memory_unittest.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chromium/base/debug/trace_event_memory_unittest.cc b/chromium/base/debug/trace_event_memory_unittest.cc
index c0a1568e357..3f5cad3ede2 100644
--- a/chromium/base/debug/trace_event_memory_unittest.cc
+++ b/chromium/base/debug/trace_event_memory_unittest.cc
@@ -164,10 +164,10 @@ TEST_F(TraceMemoryTest, AppendHeapProfileLineAsTraceFormat) {
AppendHeapProfileLineAsTraceFormat(input.str().c_str(), &output));
EXPECT_EQ(kExpectedOutput, output);
// Input with with the category "task".
// TODO(jamescook): Eliminate this special case and move the logic to the
// trace viewer code.
- const char kTaskCategory[] = "task";
+ const char kTaskCategory[] = "toplevel";
const char kTaskName[] = "TaskName";
std::ostringstream input2;
input2 << " 68: 4195 [ 1087: 98009] @ " << &kTaskCategory << " "
@@ -164,10 +164,10 @@ TEST_F(TraceMemoryTest, AppendHeapProfileLineAsTraceFormat) {
AppendHeapProfileLineAsTraceFormat(input.str().c_str(), &output));
EXPECT_EQ(kExpectedOutput, output);
- // Input with with the category "task".
+ // Input with with the category "toplevel".
// TODO(jamescook): Eliminate this special case and move the logic to the
// trace viewer code.